Stan Math Library: stan/math/prim/mat/err/validate_non_negative_index.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
validate_non_negative_index.hpp File Reference
`#include <sstream>`
`#include <stdexcept>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::validate_non_negative_index (const char *var_name, const char *expr, int val)

[ Stan Home Page ] © 2011–2016, Stan Development Team.